import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:stopmotion/config/default_settings.dart';
import 'package:stopmotion/cubit/settings_cubit.dart';
import 'package:stopmotion/ui/widgets/app_titles.dart';

class SettingsForm extends StatefulWidget {
  const SettingsForm({super.key});

  @override
  State<SettingsForm> createState() => _SettingsFormState();
}

class _SettingsFormState extends State<SettingsForm> {
  int dummyValue = DefaultSettings.defaultDummyValue;

  List<bool> _selectedDummyValue = [];

  @override
  void didChangeDependencies() {
    SettingsCubit settings = BlocProvider.of<SettingsCubit>(context);

    dummyValue = settings.getDummyValue();

    _selectedDummyValue =
        DefaultSettings.allowedDummyValues.map((e) => (e == dummyValue)).toList();

    super.didChangeDependencies();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    void saveSettings() {
      BlocProvider.of<SettingsCubit>(context).setValues(
        dummyValue: dummyValue,
      );
    }

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        const SizedBox(height: 8),
        AppTitle2(text: tr('settings_title_global')),

        // Dummy value
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            const Text('settings_label_dummy_value').tr(),
            ToggleButtons(
              onPressed: (int index) {
                setState(() {
                  dummyValue = DefaultSettings.allowedDummyValues[index];
                  for (int i = 0; i < _selectedDummyValue.length; i++) {
                    _selectedDummyValue[i] = i == index;
                  }
                });
                saveSettings();
              },
              borderRadius: const BorderRadius.all(Radius.circular(8)),
              constraints: const BoxConstraints(minHeight: 30.0, minWidth: 30.0),
              isSelected: _selectedDummyValue,
              children:
                  DefaultSettings.allowedDummyValues.map((e) => Text(e.toString())).toList(),
            ),
          ],
        ),
      ],
    );
  }
}
